<a id="packages.valory.skills.oracle_deployment_abci.handlers"></a>

# packages.valory.skills.oracle`_`deployment`_`abci.handlers

This module contains the handler for the 'oracle_deployment_abci' skill.

